@@ -288,6 +288,8 @@ class Ilo(object):
         # Bug in some ilo versions causes malformed XML
         if '<RIBCL VERSION="2.22"/>' in data:
             data = data.replace('<RIBCL VERSION="2.22"/>', '<RIBCL VERSION="2.22">')
+        if re.search(r'''= *[^"']''', data):
+            data = re.sub(r'''= *([^"'\n]+?) *\n''', r'="\1"', data)
         data = data.strip()
         if not data:
             return None
@@ -454,8 +456,8 @@ class Ilo(object):
         return self._control_tag('USER_INFO', 'ADD_USER', elements=elements,
                 attrib={'USER_LOGIN': user_login, 'USER_NAME': user_name, 'PASSWORD': password})
 
-    @untested
     def cert_fqdn(self, use_fqdn):
+        """Configure whether to use the fqdn or the short hostname for certificate requests"""
         use_fqdn = str({True: 'Yes', False: 'No'}.get(use_fqdn, use_fqdn))
         return self._control_tag('RIB_INFO', 'CERT_FQDN', attrib={'VALUE': use_fqdn})
 
@@ -513,7 +515,7 @@ class Ilo(object):
 
     def get_cert_subject_info(self):
         """Get ssl certificate subject information"""
-        return self._info_tag('RIB_INFO', 'GET_CERT_SUBJECT_INFO')
+        return self._info_tag('RIB_INFO', 'GET_CERT_SUBJECT_INFO', 'CSR_CERT_SETTINGS')
 
     def get_dir_config(self):
         """Get directory authentication configuration"""
@@ -632,7 +634,7 @@ class Ilo(object):
         return self._info_tag('SERVER_INFO', 'GET_POWER_READINGS')
 
     def get_pwreg(self):
-        """I have no idea what this does"""
+        """Get the power and power alert threshold settings"""
         return self._info_tag('SERVER_INFO', 'GET_PWREG')
 
     def get_server_auto_pwr(self):
@@ -702,10 +704,9 @@ class Ilo(object):
         elements = [etree.Element(x.upper(), VALUE=vars[x]) for x in vars if vars[x] is not None]
         return self._control_tag('RIB_INFO', 'HOTKEY_CONFIG', elements=elements)
 
-    # Not sure how this would work, and I have no relevant hardware
-    #def insert_virtual_floppy(self, device, image_location):
-    #    """Insert a virtual floppy"""
-    #    return self._control_tag('RIB_INFO', 'INSERT_VIRTUAL_FLOPPY', attrib={'IMAGE_LOCATION': image_location})
+    def import_certificate(self, certificate):
+        """Import a signed SSL certificate"""
+        return self._control_tag('RIB_INFO', 'IMPORT_CERTIFICATE', text=certificate)
 
     @untested
     def import_ssh_key(self, user_login, ssh_key):
@@ -724,6 +725,11 @@ class Ilo(object):
         key = "-----BEGIN SSH KEY-----\r\n%s %s %s\r\n----END SSH KEY-----" % (algo, key, user_login)
         return self._control_tag('RIB_INFO', 'IMPORT_SSH_KEY', text=key)
 
+    # Not sure how this would work, and I have no relevant hardware
+    #def insert_virtual_floppy(self, device, image_location):
+    #    """Insert a virtual floppy"""
+    #    return self._control_tag('RIB_INFO', 'INSERT_VIRTUAL_FLOPPY', attrib={'IMAGE_LOCATION': image_location})
+
     @untested
     def delete_ssh_key(self, user_login):
         """Delete a users SSH key"""
@@ -844,16 +850,21 @@ class Ilo(object):
         elements = [etree.Element('DEVICE', VALUE=x.upper()) for x in devices.split(',')]
         return self._control_tag('SERVER_INFO', 'SET_PERSISTENT_BOOT', elements=elements)
 
-    @untested
+    def set_pwreg(self, type, threshold=None, duration=None):
+        """Set the power alert threshold"""
+        elements = [etree.Element('PWRALERT', TYPE=type)]
+        if type.lower() != "disabled":
+            elements.append(etree.Element('PWRALERT_SETTINGS', THRESHOLD=str(threshold), DURATION=str(duration)))
+        return self._control_tag('SERVER_INFO', 'SET_PWREG', elements=elements)
+
     def set_power_cap(self, power_cap):
         """Set the power cap feature to a specific value"""
-        return self._control_taf('SERVER_INFO', 'SET_POWER_CAP', attrib={'POWER_CAP': int(power_cap)})
+        return self._control_tag('SERVER_INFO', 'SET_POWER_CAP', attrib={'POWER_CAP': str(power_cap)})
 
-    @untested
     def set_server_auto_pwr(self, setting):
         """Set the automatic power on delay setting. Valid settings are False,
            True (for minumum delay), 15, 30, 45 60 (for that amount of delay or
-           random (for a random delay op to 60 seconds. """
+           random (for a random delay of up to 60 seconds.)"""
         setting = str({True: 'Yes', False: 'No'}.get(setting, setting))
         return self._control_tag('SERVER_INFO', 'SERVER_AUTO_PWR', attrib={'VALUE': setting})
 
